abacusai.feature_record — AbacusAI documentation

# abacusai.feature_record

## Classes

`AbstractApiClass` |
`FeatureRecord` | A feature record

## Module Contents

class abacusai.feature_record.AbstractApiClass(client, id)
  __eq__(other)

    Return self==value.

  _get_attribute_as_dict(attribute)

class abacusai.feature_record.FeatureRecord(client, data=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  A feature record

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - data (dict) – the record’s current data

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict